==> openshift-model-5.1.0-sources.jar: annotations/io/fabric8/openshift/api/model/ClusterNetworkEntryBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ClusterNetworkEntryBuilder extends ClusterNetworkEntryFluentImpl<ClusterNetworkEntryBuilder> implements VisitableBuilder<ClusterNetworkEntry,ClusterNetworkEntryBuilder> {

    ClusterNetworkEntryFluent<?> fluent;
    Boolean validationEnabled;

    public ClusterNetworkEntryBuilder() {
        this(true);
    }

    public ClusterNetworkEntryBuilder(Boolean validationEnabled) {
        this(new ClusterNetworkEntry(), validationEnabled);
    }

    public ClusterNetworkEntryBuilder(ClusterNetworkEntryFluent<?> fluent) {
        this(fluent, true);
    }

    public ClusterNetworkEntryBuilder(ClusterNetworkEntryFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ClusterNetworkEntry(), validationEnabled);
    }

    public ClusterNetworkEntryBuilder(ClusterNetworkEntryFluent<?> fluent,ClusterNetworkEntry instance) {
        this(fluent, instance, true);
    }

    public ClusterNetworkEntryBuilder(ClusterNetworkEntryFluent<?> fluent,ClusterNetworkEntry instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCidr(instance.getCidr()); 
        fluent.withHostSubnetLength(instance.getHostSubnetLength()); 
        this.validationEnabled = validationEnabled; 
    }

    public ClusterNetworkEntryBuilder(ClusterNetworkEntry instance) {
        this(instance,true);
    }

    public ClusterNetworkEntryBuilder(ClusterNetworkEntry instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withCidr(instance.getCidr()); 
        this.withHostSubnetLength(instance.getHostSubnetLength()); 
        this.validationEnabled = validationEnabled; 
    }

    public ClusterNetworkEntry build() {
        ClusterNetworkEntry buildable = new ClusterNetworkEntry(fluent.getCidr(),fluent.getHostSubnetLength());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ClusterNetworkEntryBuilder that = (ClusterNetworkEntryBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-5.3.2-sources.jar: annotations/io/fabric8/openshift/api/model/ClusterNetworkEntryBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ClusterNetworkEntryBuilder extends ClusterNetworkEntryFluentImpl<ClusterNetworkEntryBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<ClusterNetworkEntry,ClusterNetworkEntryBuilder> {

    ClusterNetworkEntryFluent<?> fluent;
    Boolean validationEnabled;

    public ClusterNetworkEntryBuilder() {
        this(true);
    }

    public ClusterNetworkEntryBuilder(Boolean validationEnabled) {
        this(new ClusterNetworkEntry(), validationEnabled);
    }

    public ClusterNetworkEntryBuilder(ClusterNetworkEntryFluent<?> fluent) {
        this(fluent, true);
    }

    public ClusterNetworkEntryBuilder(ClusterNetworkEntryFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ClusterNetworkEntry(), validationEnabled);
    }

    public ClusterNetworkEntryBuilder(ClusterNetworkEntryFluent<?> fluent,ClusterNetworkEntry instance) {
        this(fluent, instance, true);
    }

    public ClusterNetworkEntryBuilder(ClusterNetworkEntryFluent<?> fluent,ClusterNetworkEntry instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCidr(instance.getCidr()); 
        fluent.withHostSubnetLength(instance.getHostSubnetLength()); 
        this.validationEnabled = validationEnabled; 
    }

    public ClusterNetworkEntryBuilder(ClusterNetworkEntry instance) {
        this(instance,true);
    }

    public ClusterNetworkEntryBuilder(ClusterNetworkEntry instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withCidr(instance.getCidr()); 
        this.withHostSubnetLength(instance.getHostSubnetLength()); 
        this.validationEnabled = validationEnabled; 
    }

    public ClusterNetworkEntry build() {
        ClusterNetworkEntry buildable = new ClusterNetworkEntry(fluent.getCidr(),fluent.getHostSubnetLength());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ClusterNetworkEntryBuilder that = (ClusterNetworkEntryBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
